#
# spec file for package libfdata
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libfdata
%define lname	libfdata1
Version:        20240415
Release:        1.3
Summary:        Library to provide generic file data functions
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libfdata
Source:         https://github.com/libyal/libfdata/releases/download/%version/libfdata-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libfdata/releases/download/%version/libfdata-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
# Various notes: https://en.opensuse.org/libyal

%description
Library to provide generic file data functions for the libyal family of libraries.

%package -n %lname
Summary:        Library to provide generic file data functions
Group:          System/Libraries

%description -n %lname
Library to provide generic file data functions for the libyal family of libraries.

%package devel
Summary:        Development files for libfdata
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Library to provide generic file data functions for the libyal family of libraries.

This subpackage contains libraries and header files for developing
applications that want to make use of libfdata.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
find %buildroot -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libfdata.so.*

%files devel
%_includedir/libfdata.h
%_includedir/libfdata/
%_libdir/libfdata.so
%_libdir/pkgconfig/libfdata.pc
%_mandir/man3/libfdata.3*

%changelog
* Mon Apr 15 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240415
  * No changelog was provided
* Sun Jan 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240114
  * No user-relevant changes
- Delete libfdata-20211023-1TB-fix.patch: this patch is bogus.
  The return value is used exclusively for status, but
  offsets/sizes are in the 3rd paramter instead.
* Sun Mar 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230319
  * Removed no longer used tree support
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Sep  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirements
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220111
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Tue Mar 22 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- Add libfdata-20211023-1TB-fix.patch
  * Fixes bug associated with image offsets beyond 1TB
  * see https://github.com/libyal/libbde/issues/47
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211023
  * No changelog was provided
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210414 (fa85a383)
  * No changelog was provided
- Add system-libs.patch
* Tue Dec 29 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201129
  * changes for libcdata
  * small changes in vector
  * removed no longer used B-tree support
  * worked on stream
  * worked on list
  * changes for libfcache get/set value by identifier
- remove BuildRequires pkg-config
- add COPYING* to %%license line
* Mon Apr 15 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181124
  * Changes for libfcache get/set value by identifier
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20170112
* Sun Jan 31 2016 Greg.Freemyer@gmail.com
- update to v0~20150825
  * worked on stream
  - added get mapped range function
  - added mapped size
  * worked on btree search flags
  * added support for less equal and greater equal for compare functions
  in libfdata_btree_node_get_sub_node_data_range_by_key
* Thu Jan  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150104
  * libfcache integration improvements
  * btree improvements and tests
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- remove %%if for opensuse version - no longer needed since all of libyal is in security:forensics
- start using libcstring from OBS, not internal version
* Mon Sep  1 2014 Greg.Freemyer@gmail.com
- initial package in OBS (v0~20140601)
